==> haskell-texmath-0.12.8.11-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-texmath.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 texmath
version:              0.12.8.11
visibility:           public
id:                   texmath-0.12.8.11-1WaokX5tZUN5NU3vRyNWnR
key:                  texmath-0.12.8.11-1WaokX5tZUN5NU3vRyNWnR
license:              GPL-2.0-only
maintainer:           jgm@berkeley.edu
author:               John MacFarlane, Matthew Pickering
stability:            Experimental
homepage:             http://github.com/jgm/texmath
synopsis:             Conversion between math formats.
description:
    The texmath library provides functions to read
    and write TeX math, presentation MathML, and OMML (Office
    Math Markup Language, used in Microsoft Office).  Support is also
    included for converting math formats to Gnu eqn, typst, and pandoc'\''s
    native format (allowing conversion, via pandoc, to a variety of
    different markup formats).  The TeX reader supports basic LaTeX
    and AMS extensions, and it can parse and apply LaTeX macros.
    (See <https://johnmacfarlane.net/texmath here> for a live demo of
    bidirectional conversion between LaTeX and MathML.)

    The package also includes several utility modules which may be
    useful for anyone looking to manipulate either TeX math or
    MathML.  For example, a copy of the MathML operator dictionary is
    included.

    Use the @executable@ flag to install a standalone
    executable, @texmath@, that converts formulas from one
    format to another. (Use the @--help@ flag for a description of all
    functionality).

    Use the @server@ flag to install a web server, @texmath-server@,
    that exposes a JSON API allowing conversion of individual
    formulas and batches of formulas.

category:             Text
abi:                  3b35f7b6a8127a657b5a3fc404fef4b2
exposed:              True
exposed-modules:
    Text.TeXMath Text.TeXMath.Readers.MathML
    Text.TeXMath.Readers.MathML.EntityMap
    Text.TeXMath.Readers.MathML.MMLDict Text.TeXMath.Readers.OMML
    Text.TeXMath.Readers.TeX Text.TeXMath.Readers.TeX.Macros
    Text.TeXMath.Shared Text.TeXMath.TeX Text.TeXMath.Types
    Text.TeXMath.Unicode.Fonts Text.TeXMath.Unicode.ToTeX
    Text.TeXMath.Unicode.ToUnicode Text.TeXMath.Writers.Eqn
    Text.TeXMath.Writers.MathML Text.TeXMath.Writers.OMML
    Text.TeXMath.Writers.Pandoc Text.TeXMath.Writers.TeX
    Text.TeXMath.Writers.Typst

hidden-modules:       Text.TeXMath.Readers.TeX.Commands Paths_texmath
import-dirs:          /usr/lib/ghc-9.4.8/site-local/texmath-0.12.8.11
library-dirs:         /usr/lib/ghc-9.4.8/site-local/texmath-0.12.8.11
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/texmath-0.12.8.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.4.8/texmath-0.12.8.11
hs-libraries:         HStexmath-0.12.8.11-1WaokX5tZUN5NU3vRyNWnR
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2
    pandoc-types-1.23.1-4PdVS2SJqvF1JyHlvdR6Jk parsec-3.1.16.1
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q syb-0.7.3-6hZpCMnOgIw3sb7LbwnFLW
    text-2.0.2 typst-symbols-0.1.6-8fTeUIeuBH16qqbNakBZL7
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG

haddock-interfaces:   /usr/share/doc/haskell-texmath/html/texmath.haddock
haddock-html:         /usr/share/doc/haskell-texmath/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-texmath-0.12.8.11-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-texmath.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 texmath
version:              0.12.8.11
visibility:           public
id:                   texmath-0.12.8.11-DFroRUep5rTSTgYxCaAxn
key:                  texmath-0.12.8.11-DFroRUep5rTSTgYxCaAxn
license:              GPL-2.0-only
maintainer:           jgm@berkeley.edu
author:               John MacFarlane, Matthew Pickering
stability:            Experimental
homepage:             http://github.com/jgm/texmath
synopsis:             Conversion between math formats.
description:
    The texmath library provides functions to read
    and write TeX math, presentation MathML, and OMML (Office
    Math Markup Language, used in Microsoft Office).  Support is also
    included for converting math formats to Gnu eqn, typst, and pandoc'\''s
    native format (allowing conversion, via pandoc, to a variety of
    different markup formats).  The TeX reader supports basic LaTeX
    and AMS extensions, and it can parse and apply LaTeX macros.
    (See <https://johnmacfarlane.net/texmath here> for a live demo of
    bidirectional conversion between LaTeX and MathML.)

    The package also includes several utility modules which may be
    useful for anyone looking to manipulate either TeX math or
    MathML.  For example, a copy of the MathML operator dictionary is
    included.

    Use the @executable@ flag to install a standalone
    executable, @texmath@, that converts formulas from one
    format to another. (Use the @--help@ flag for a description of all
    functionality).

    Use the @server@ flag to install a web server, @texmath-server@,
    that exposes a JSON API allowing conversion of individual
    formulas and batches of formulas.

category:             Text
abi:                  d4b3752c5317ce9ff4ab5e5902b29e8b
exposed:              True
exposed-modules:
    Text.TeXMath Text.TeXMath.Readers.MathML
    Text.TeXMath.Readers.MathML.EntityMap
    Text.TeXMath.Readers.MathML.MMLDict Text.TeXMath.Readers.OMML
    Text.TeXMath.Readers.TeX Text.TeXMath.Readers.TeX.Macros
    Text.TeXMath.Shared Text.TeXMath.TeX Text.TeXMath.Types
    Text.TeXMath.Unicode.Fonts Text.TeXMath.Unicode.ToTeX
    Text.TeXMath.Unicode.ToUnicode Text.TeXMath.Writers.Eqn
    Text.TeXMath.Writers.MathML Text.TeXMath.Writers.OMML
    Text.TeXMath.Writers.Pandoc Text.TeXMath.Writers.TeX
    Text.TeXMath.Writers.Typst

hidden-modules:       Text.TeXMath.Readers.TeX.Commands Paths_texmath
import-dirs:          /usr/lib/ghc-9.4.8/site-local/texmath-0.12.8.11
library-dirs:         /usr/lib/ghc-9.4.8/site-local/texmath-0.12.8.11
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/texmath-0.12.8.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.4.8/texmath-0.12.8.11
hs-libraries:         HStexmath-0.12.8.11-DFroRUep5rTSTgYxCaAxn
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2
    pandoc-types-1.23.1-3GPCRlYgi7A9JkeDiKYcZT parsec-3.1.16.1
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q syb-0.7.3-CwqNo0h5dXa2Bf4xbRg7w6
    text-2.0.2 typst-symbols-0.1.6-8fTeUIeuBH16qqbNakBZL7
    xml-1.3.14-Lx2FeToC7XoDX0aDGC9dRG

haddock-interfaces:   /usr/share/doc/haskell-texmath/html/texmath.haddock
haddock-html:         /usr/share/doc/haskell-texmath/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
